@@ -4,11 +4,22 @@
         .. automethod:: run
 """
 
-from docutils.parsers.rst import Directive
+from typing import cast
 
+from docutils.parsers.rst import Directive
+from sphinx.environment import BuildEnvironment
+
+from .domain import BibtexDomain
 from .foot_nodes import footbibliography
 
 
+def new_foot_bibliography_id(env: BuildEnvironment) -> None:
+    """Generate a new footbibliography id for the given build environment."""
+    env.temp_data["bibtex_foot_bibliography_id"] = \
+        'bibtex-footbibliography-%s-%s' % (
+            env.docname, env.new_serialno('bibtex'))
+
+
 class FootBibliographyDirective(Directive):
 
     """Class for processing the :rst:dir:`footbibliography` directive.
@@ -32,8 +43,9 @@ class FootBibliographyDirective(Directive):
         that is to be transformed to the entries of the bibliography.
         """
         env = self.state.document.settings.env
-        for bibfile in env.bibtex_cache.bibfiles:
+        domain = cast(BibtexDomain, env.get_domain('cite'))
+        for bibfile in domain.bibfiles:
             env.note_dependency(bibfile)
-        id_ = env.bibtex_cache.foot_current_id[env.docname]
-        env.bibtex_cache.new_foot_current_id(env)
+        id_ = env.temp_data["bibtex_foot_bibliography_id"]
+        new_foot_bibliography_id(env)
         return [footbibliography('', ids=[id_])]
