@@ -1,12 +1,5 @@
-"""
-    test_issue91
-    ~~~~~~~~~~~~
-
-    Test bibtex_default_style config value.
-"""
-
+import common
 import pytest
-import re
 
 
 @pytest.mark.sphinx('html', testroot='issue91')
@@ -16,5 +9,5 @@ def test_issue91(app, warning):
     # default style is plain; check output
     output = (app.outdir / "index.html").read_text()
     # ensure Man09 is cited with plain style and not with alpha style
-    assert len(re.findall("\\[1\\]", output)) == 1
-    assert len(re.findall("\\[Man09\\]", output)) == 0
+    assert len(common.html_citation_refs(label="1").findall(output)) == 1
+    assert len(common.html_citation_refs(label="Man09").findall(output)) == 0
